@@ -19,11 +19,9 @@ def combine_nexuses(nexuslist):
     charpos = 0
     for nex_id, nex in enumerate(nexuslist, 1):
         check_for_valid_NexusReader(nex, required_blocks=['data'])
-
+        
         if hasattr(nex, 'short_filename'):
             nexus_label = os.path.splitext(nex.short_filename)[0]
-        elif hasattr(nex, 'label'):
-            nexus_label = nex.label
         else:
             nexus_label = str(nex_id)
         
